/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.edge;


import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;
import de.hft.stuttgart.citydoctor2.math.MovedPolygon;
import de.hft.stuttgart.citydoctor2.math.Vector3d;

public class MeshSurface {
	
	private List<CDPolygonNs> polygons;
	
	public static MeshSurface of(Geometry geom) {
		List<CDPolygonNs> polygonList = new ArrayList<>();
		
		Map<Vector3d, Coordinate3d> pointMap = new HashMap<>();
		Vector3d moveBy = geom.calculateBoundingBox().getBox()[0];
		for (Polygon p : geom.getPolygons()) {
			MovedPolygon mp = MovedPolygon.ofPolygon(p, moveBy);
			CDPolygonNs poly = CDPolygonNs.of(mp, pointMap);
			polygonList.add(poly);
		}
		return new MeshSurface(polygonList);
	}
	
	public MeshSurface(List<CDPolygonNs> polygons) {
		this.polygons = polygons;
	}
	
	public List<CDPolygonNs> getPolygons() {
		return polygons;
	}

}
