/*-
 *  Copyright 2023 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check;

import de.hft.stuttgart.citydoctor2.check.error.AllPolygonsWrongOrientationError;
import de.hft.stuttgart.citydoctor2.check.error.AttributeInvalidError;
import de.hft.stuttgart.citydoctor2.check.error.AttributeMissingError;
import de.hft.stuttgart.citydoctor2.check.error.AttributeValueWrongError;
import de.hft.stuttgart.citydoctor2.check.error.ConsecutivePointSameError;
import de.hft.stuttgart.citydoctor2.check.error.DependenciesNotMetError;
import de.hft.stuttgart.citydoctor2.check.error.MultipleConnectedComponentsError;
import de.hft.stuttgart.citydoctor2.check.error.NestedRingError;
import de.hft.stuttgart.citydoctor2.check.error.NonManifoldEdgeError;
import de.hft.stuttgart.citydoctor2.check.error.NonManifoldVertexError;
import de.hft.stuttgart.citydoctor2.check.error.NonPlanarPolygonDistancePlaneError;
import de.hft.stuttgart.citydoctor2.check.error.NonPlanarPolygonNormalsDeviation;
import de.hft.stuttgart.citydoctor2.check.error.NotCeilingError;
import de.hft.stuttgart.citydoctor2.check.error.NotFloorError;
import de.hft.stuttgart.citydoctor2.check.error.NotGroundError;
import de.hft.stuttgart.citydoctor2.check.error.NotWallError;
import de.hft.stuttgart.citydoctor2.check.error.NullAreaError;
import de.hft.stuttgart.citydoctor2.check.error.PointTouchesEdgeError;
import de.hft.stuttgart.citydoctor2.check.error.PolygonHoleOutsideError;
import de.hft.stuttgart.citydoctor2.check.error.PolygonInteriorDisconnectedError;
import de.hft.stuttgart.citydoctor2.check.error.PolygonIntersectingRingsError;
import de.hft.stuttgart.citydoctor2.check.error.PolygonSameOrientationError;
import de.hft.stuttgart.citydoctor2.check.error.PolygonWrongOrientationError;
import de.hft.stuttgart.citydoctor2.check.error.RingDuplicatePointError;
import de.hft.stuttgart.citydoctor2.check.error.RingEdgeIntersectionError;
import de.hft.stuttgart.citydoctor2.check.error.RingNotClosedError;
import de.hft.stuttgart.citydoctor2.check.error.RingTooFewPointsError;
import de.hft.stuttgart.citydoctor2.check.error.SchematronError;
import de.hft.stuttgart.citydoctor2.check.error.SolidNotClosedError;
import de.hft.stuttgart.citydoctor2.check.error.SolidSelfIntError;
import de.hft.stuttgart.citydoctor2.check.error.SurfaceUnfragmentedError;
import de.hft.stuttgart.citydoctor2.check.error.DegeneratedRingError;
import de.hft.stuttgart.citydoctor2.check.error.TooFewPolygonsError;
import de.hft.stuttgart.citydoctor2.check.error.UnknownCheckError;

/**
 * Visitor pattern interface to access errors. This is to determine the type of
 * an error without resorting to endless instanceof structures.
 * 
 * @author Matthias Betz
 *
 */
public interface ErrorVisitor {

	public void visit(PolygonHoleOutsideError err);

	public void visit(NonManifoldEdgeError err);

	public void visit(MultipleConnectedComponentsError err);

	public void visit(NestedRingError err);

	public void visit(NonManifoldVertexError err);

	public void visit(PolygonWrongOrientationError err);

	public void visit(PolygonSameOrientationError err);

	public void visit(SolidNotClosedError err);

	public void visit(DependenciesNotMetError err);

	public void visit(UnknownCheckError err);

	public void visit(RingNotClosedError err);

	public void visit(ConsecutivePointSameError err);

	public void visit(AllPolygonsWrongOrientationError err);

	public void visit(PolygonInteriorDisconnectedError err);

	public void visit(NullAreaError err);

	public void visit(RingTooFewPointsError err);

	public void visit(NonPlanarPolygonNormalsDeviation err);

	public void visit(NonPlanarPolygonDistancePlaneError err);

	public void visit(PolygonIntersectingRingsError err);

	public void visit(SolidSelfIntError err);

	public void visit(TooFewPolygonsError err);

	public void visit(RingDuplicatePointError err);

	public void visit(RingEdgeIntersectionError err);

	public void visit(PointTouchesEdgeError err);

	public void visit(NotCeilingError err);

	public void visit(NotFloorError err);

	public void visit(NotWallError err);

	public void visit(NotGroundError err);

	public void visit(CheckError err);
	
	public void visit(SchematronError err);
	
	public void visit(SurfaceUnfragmentedError err);
	
	public void visit(DegeneratedRingError err);
	
	public void visit(AttributeMissingError err);
	
	public void visit(AttributeValueWrongError err);

	public void visit(AttributeInvalidError cdErr);

}
