/*-
 *  Copyright 2022 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ErrorReport;
import de.hft.stuttgart.citydoctor2.check.ErrorType;
import de.hft.stuttgart.citydoctor2.check.ErrorVisitor;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.datastructure.CityObject;
import de.hft.stuttgart.citydoctor2.datastructure.GmlElement;

public class AttributeInvalidError implements CheckError {
	
	private static final long serialVersionUID = 346311592089394220L;

	public static final ErrorId ID = new ErrorId("SE_ATTRIBUTE_INVALID");

	private CityObject co;
	private String childId;
	private String nameOfAttribute;

	public AttributeInvalidError(CityObject co, String childId, String nameOfAttribute) {
		this.co = co;
		this.childId = childId;
		this.nameOfAttribute = nameOfAttribute;
	}

	@Override
	public ErrorType getType() {
		return ErrorType.ERROR;
	}

	@Override
	public ErrorId getErrorId() {
		return ID;
	}
	
	public String getChildId() {
		return childId;
	}
	
	public String getNameOfAttribute() {
		return nameOfAttribute;
	}

	@Override
	public GmlElement getFeature() {
		return co;
	}

	@Override
	public void accept(ErrorVisitor errorVisitor) {
		errorVisitor.visit(this);
	}

	@Override
	public boolean accept(HealingMethod method, ModificationListener l) {
		return method.visit(this, l);
	}

	@Override
	public void report(ErrorReport report) {
		report.add("childId", childId);
		report.add("name", nameOfAttribute);
	}

}
