/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import de.hft.stuttgart.citydoctor2.check.CheckError;
import de.hft.stuttgart.citydoctor2.check.ErrorId;
import de.hft.stuttgart.citydoctor2.check.ErrorReport;
import de.hft.stuttgart.citydoctor2.check.ErrorType;
import de.hft.stuttgart.citydoctor2.check.ErrorVisitor;
import de.hft.stuttgart.citydoctor2.check.HealingMethod;
import de.hft.stuttgart.citydoctor2.check.ModificationListener;
import de.hft.stuttgart.citydoctor2.datastructure.GmlElement;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;

/**
 * If an inner ring is with in the boundaries of another, this error is created.
 * 
 * @author Matthias Betz
 *
 */
public class NestedRingError implements CheckError {

	private static final long serialVersionUID = -3396113374745830193L;
	
	private Polygon p;
	private LinearRing innerRing;
	private LinearRing withinRing;

	public NestedRingError(Polygon p, LinearRing innerRing, LinearRing withinRing) {
		this.p = p;
		this.innerRing = innerRing;
		this.withinRing = withinRing;
	}

	public Polygon getPolygon() {
		return p;
	}

	public LinearRing getInnerRing() {
		return innerRing;
	}

	public LinearRing getWithinRing() {
		return withinRing;
	}

	@Override
	public void report(ErrorReport report) {
		report.add(p);
		report.add(innerRing);
	}

	@Override
	public void accept(ErrorVisitor errorVisitor) {
		errorVisitor.visit(this);
	}

	@Override
	public boolean accept(HealingMethod method, ModificationListener l) {
		return method.visit(this, l);
	}

	@Override
	public String toString() {
		return "NestedRingError [p=" + p + ", innerRing=" + innerRing + "]";
	}

	@Override
	public ErrorType getType() {
		return ErrorType.ERROR;
	}

	@Override
	public ErrorId getErrorId() {
		return ErrorId.GE_P_INNER_RINGS_NESTED;
	}

	@Override
	public GmlElement getFeature() {
		return getPolygon();
	}

}
