/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.datastructure;

import de.hft.stuttgart.citydoctor2.utils.CopyHandler;
import de.hft.stuttgart.citydoctor2.utils.Copyable;

public class BuildingPart extends AbstractBuilding {
	
	private static final long serialVersionUID = 8200322261958679163L;
	
	private Building parent;
	
	private BuildingPart() {
	}
	
	public BuildingPart(Building parent) {
		this.parent = parent;
		parent.addBuildingPart(this);
	}
	
	public Building getParent() {
		return parent;
	}
	
	@Override
	public FeatureType getFeatureType() {
		return FeatureType.BUILDING_PART;
	}

	@Override
	public String toString() {
		return "BuildingPart [id=" + getGmlId() + "]";
	}
	
	@Override
	public void fillValues(Copyable original, CopyHandler handler) {
		super.fillValues(original, handler);
		BuildingPart originalPart = (BuildingPart) original;
		parent = handler.getCopyInstance(originalPart.parent);
	}
	
	@Override
	public void collectInstances(CopyHandler handler) {
		super.collectInstances(handler);
		handler.addInstance(parent);
	}

	@Override
	public Copyable createCopyInstance() {
		return new BuildingPart();
	}

}
