/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.datastructure;

import de.hft.stuttgart.citydoctor2.check.Checkable;
import de.hft.stuttgart.citydoctor2.utils.CopyHandler;
import de.hft.stuttgart.citydoctor2.utils.Copyable;

/**
 * A general GML element that has a gml id
 * 
 * @author Matthias Betz
 *
 */
public abstract class GmlElement extends Checkable implements Copyable {

	private static final long serialVersionUID = -3242505393303017359L;

	private GmlId gmlId;

	public void setGmlId(GmlId id) {
		gmlId = id;
	}

	@Override
	public GmlId getGmlId() {
		if (gmlId == null) {
			gmlId = GmlId.generateId();
		}
		return gmlId;
	}
	
	public boolean hasExistingGmlId() {
		return gmlId != null && !gmlId.isGenerated();
	}
	
	@Override
	public void fillValues(Copyable original, CopyHandler handler) {
		GmlElement originalElement = (GmlElement) original;
		// generate gml id before copying
		gmlId = originalElement.getGmlId();
	}
	
}
