/*-
 *  Copyright 2022 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.datastructure;

import java.util.ArrayList;
import java.util.List;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.citygml4j.core.model.relief.TINRelief;
import org.citygml4j.core.util.geometry.GeometryFactory;
import org.xmlobjects.gml.model.geometry.primitives.AbstractRingProperty;
import org.xmlobjects.gml.model.geometry.primitives.Triangle;
import org.xmlobjects.gml.model.geometry.primitives.TriangleArrayProperty;
import org.xmlobjects.gml.model.geometry.primitives.TriangulatedSurface;

import de.hft.stuttgart.citydoctor2.check.Check;
import de.hft.stuttgart.citydoctor2.parser.ParserConfiguration;
import de.hft.stuttgart.citydoctor2.utils.CityGmlUtils;

public class TinObject extends CityObject {

	private static final Logger logger = LogManager.getLogger(TinObject.class);

	private static final long serialVersionUID = 1910744427384724422L;

	private TINRelief gmlRelief;

	public TinObject(TINRelief gmlRelief) {
		this.gmlRelief = gmlRelief;
	}

	@Override
	public void accept(Check c) {
		super.accept(c);
		if (c.canExecute(this)) {
			c.check(this);
		}
	}

	@Override
	public TinObject createCopyInstance() {
		return new TinObject(gmlRelief);
	}

	@Override
	public void reCreateGeometries(GeometryFactory factory, ParserConfiguration config) {
		if (getGeometries().isEmpty()) {
			return;
		}
		if (getGeometries().size() > 1) {
			logger.warn("A TINRelief can only have one geometry but found {}. Using the first geometry found",
					getGeometries().size());
		}
		Geometry geom = getGeometries().get(0);
		List<Triangle> triangles = new ArrayList<>();
		TriangulatedSurface surface = new TriangulatedSurface();
		surface.setPatches(new TriangleArrayProperty(triangles));
		for (Polygon poly : geom.getPolygons()) {
			LinearRing ring = poly.getExteriorRing();
			Triangle t = new Triangle();
			t.setExterior(new AbstractRingProperty(CityGmlUtils.createGmlRing(factory, config, ring)));
			triangles.add(t);
		}
	}

	@Override
	public TINRelief getGmlObject() {
		return gmlRelief;
	}

	@Override
	public void unsetGmlGeometries() {
		gmlRelief.setTin(null);
	}

	@Override
	public FeatureType getFeatureType() {
		return FeatureType.LAND;
	}

}
