/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.math;

import java.util.ArrayList;
import java.util.List;

import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;

/**
 * A two dimensional ring containing the 2d vertices
 * 
 * @author Matthias Betz
 *
 */
public class Ring2d {

	private List<Vector2d> ringVertices;
	private LinearRing original;
	
	public static Ring2d of(MovedRing movedRing) {
		return of(movedRing, ProjectionAxis.of(movedRing));
	}
	
	public static Ring2d of(LinearRing ring, ProjectionAxis axis) {
		List<Vector2d> projectedVertices = new ArrayList<>();
		for (Vertex v : ring.getVertices()) {
			projectedVertices.add(axis.project(v));
		}
		return new Ring2d(projectedVertices, ring);
	}
	
	public static Ring2d of(MovedRing ring, ProjectionAxis axis) {
		List<Vector2d> projectedVertices = new ArrayList<>();
		for (Vector3d v : ring.getVertices()) {
			projectedVertices.add(axis.project(v));
		}
		return new Ring2d(projectedVertices, ring.getOriginal());
	}
	

	public Ring2d(List<Vector2d> ringVertices, LinearRing original) {
		this.ringVertices = ringVertices;
		this.original = original;
	}

	public List<Vector2d> getVertices() {
		return ringVertices;
	}

	public LinearRing getOriginal() {
		return original;
	}

	public boolean containsPoint(Vector2d v) {
		boolean result = false;
		for (int i = 0, j = ringVertices.size() - 1; i < ringVertices.size(); j = i++) {
			Vector2d p1 = ringVertices.get(i);
			Vector2d p2 = ringVertices.get(j);
			if ((p1.getY() > v.getY()) != (p2.getY() > v.getY()) && (v
					.getX() < (p2.getX() - p1.getX()) * (v.getY() - p1.getY()) / (p2.getY() - p1.getY()) + p1.getX())) {
				result = !result;
			}
		}
		return result;
	}

}
