/*-
 *  Copyright 2022 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.List;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.QualityAdeErrorVisitor;
import de.hft.stuttgart.citydoctor2.datastructure.Building;
import de.hft.stuttgart.citydoctor2.datastructure.GmlId;
import de.hft.stuttgart.quality.model.properties.AbstractErrorProperty;
import de.hft.stuttgart.quality.model.types.AbstractError;
import de.hft.stuttgart.quality.model.types.SemanticAttributeInvalidError;
import de.hft.stuttgart.quality.model.types.ValidationResult;

public class AttributeInvalidErrorTest {

	@Test
	public void testConvertToQualityAdeDatastructure() {
		Building b = new Building();
		GmlId id = new GmlId("testid");
		b.setGmlId(id);
		AttributeInvalidError err = new AttributeInvalidError(b, "childid", "attr");
		
		ValidationResult result = new ValidationResult();
		QualityAdeErrorVisitor visitor = new QualityAdeErrorVisitor(result);
		err.accept(visitor);
		List<AbstractErrorProperty> errors = result.getErrors();
		assertEquals(1, errors.size());
		AbstractError validationError = errors.get(0).getObject();
		assertTrue(validationError instanceof SemanticAttributeInvalidError);
		
		SemanticAttributeInvalidError adeErr = (SemanticAttributeInvalidError) validationError;
		assertEquals("childid", adeErr.getChildId());
		assertEquals("attr", adeErr.getAttributeName());

	}

}
