/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.QualityAdeErrorVisitor;
import de.hft.stuttgart.citydoctor2.datastructure.ConcretePolygon;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.datastructure.GeometryType;
import de.hft.stuttgart.citydoctor2.datastructure.GmlId;
import de.hft.stuttgart.citydoctor2.datastructure.Lod;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;
import de.hft.stuttgart.quality.model.properties.AbstractErrorProperty;
import de.hft.stuttgart.quality.model.types.AbstractError;
import de.hft.stuttgart.quality.model.types.ValidationResult;

public class NonManifoldVertexErrorTest {

	@Test
	public void testConvertToQualityAdeDatastructure() {
		Geometry geom = new Geometry(GeometryType.SOLID, Lod.LOD2);
		GmlId geomId = new GmlId("geomId");
		geom.setGmlId(geomId);
		Polygon p1 = new ConcretePolygon();
		GmlId p1Id = new GmlId("p1Id");
		p1.setGmlId(p1Id);
		Polygon p2 = new ConcretePolygon();
		GmlId p2Id = new GmlId("p2Id");
		p2.setGmlId(p2Id);
		Polygon p3 = new ConcretePolygon();
		GmlId p3Id = new GmlId("p3Id");
		p3.setGmlId(p3Id);
		
		List<List<Polygon>> components = new ArrayList<>();
		List<Polygon> component1 = new ArrayList<>();
		component1.add(p1);
		component1.add(p2);
		components.add(component1);
		List<Polygon> component2 = new ArrayList<>();
		component2.add(p3);
		components.add(component2);
		
		Vertex v1 = new Vertex(1, 2, 3);

		NonManifoldVertexError err = new NonManifoldVertexError(geom, components, v1);
		
		ValidationResult result = new ValidationResult();
		QualityAdeErrorVisitor visitor = new QualityAdeErrorVisitor(result);
		err.accept(visitor);
		List<AbstractErrorProperty> errors = result.getErrors();
		assertEquals(1, errors.size());
		AbstractError ae = errors.get(0).getObject();
		assertTrue(ae instanceof de.hft.stuttgart.quality.model.types.NonManifoldVertexError);
		
		var validationError = (de.hft.stuttgart.quality.model.types.NonManifoldVertexError) ae;
		assertEquals(geomId.getGmlString(), validationError.getGeometryId());
		assertEquals(1, validationError.getVertex().getValue().get(0), 0.0001);
	}

}
