/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.List;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.QualityAdeErrorVisitor;
import de.hft.stuttgart.citydoctor2.datastructure.Edge;
import de.hft.stuttgart.citydoctor2.datastructure.GmlId;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing.LinearRingType;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;
import de.hft.stuttgart.quality.model.properties.AbstractErrorProperty;
import de.hft.stuttgart.quality.model.types.AbstractError;
import de.hft.stuttgart.quality.model.types.RingSelfIntersectionError;
import de.hft.stuttgart.quality.model.types.ValidationResult;

public class PointTouchesEdgeErrorTest {

	@Test
	public void testConvertToQualityAdeDatastructure() {
		LinearRing lr = new LinearRing(LinearRingType.EXTERIOR);
		GmlId id = new GmlId("id");
		lr.setGmlId(id);
		Vertex v1 = new Vertex(1, 2, 3);
		Vertex v2 = new Vertex(4, 5, 6);
		Edge e1 = new Edge(v1, v2);

		PointTouchesEdgeError err = new PointTouchesEdgeError(lr, e1, v1);
		
		ValidationResult result = new ValidationResult();
		QualityAdeErrorVisitor visitor = new QualityAdeErrorVisitor(result);
		err.accept(visitor);
		List<AbstractErrorProperty> errors = result.getErrors();
		assertEquals(1, errors.size());
		AbstractError ae = errors.get(0).getObject();
		assertTrue(ae instanceof RingSelfIntersectionError);
		
		RingSelfIntersectionError error = (RingSelfIntersectionError) ae;
		assertEquals(id.getGmlString(), error.getLinearRingId());
		assertEquals(1, error.getVertex1().getValue().get(0), 0.00001);
		assertEquals(1, error.getEdge1().getObject().getFrom().getValue().get(0), 0.000001);
		assertEquals(4, error.getEdge1().getObject().getTo().getValue().get(0), 0.000001);
	}

}
