/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check.error;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.QualityAdeErrorVisitor;
import de.hft.stuttgart.citydoctor2.datastructure.ConcretePolygon;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.datastructure.GeometryType;
import de.hft.stuttgart.citydoctor2.datastructure.GmlId;
import de.hft.stuttgart.citydoctor2.datastructure.Lod;
import de.hft.stuttgart.citydoctor2.datastructure.Polygon;
import de.hft.stuttgart.citydoctor2.utils.PolygonIntersection;
import de.hft.stuttgart.quality.model.properties.AbstractErrorProperty;
import de.hft.stuttgart.quality.model.types.AbstractError;
import de.hft.stuttgart.quality.model.types.SolidSelfIntersectionError;
import de.hft.stuttgart.quality.model.types.ValidationResult;

public class SolidSelfIntErrorTest {

	@Test
	public void testConvertToQualityAdeDatastructure() {
		Geometry geom = new Geometry(GeometryType.SOLID, Lod.LOD2);
		GmlId geomId = new GmlId("geomId");
		geom.setGmlId(geomId);
		Polygon p1 = new ConcretePolygon();
		GmlId p1Id = new GmlId("p1Id");
		p1.setGmlId(p1Id);
		Polygon p2 = new ConcretePolygon();
		GmlId p2Id = new GmlId("p2Id");
		p2.setGmlId(p2Id);
		PolygonIntersection inter = PolygonIntersection.lines(null, p1, p2);
		List<PolygonIntersection> intersections = new ArrayList<>();
		intersections.add(inter);
		
		SolidSelfIntError err = new SolidSelfIntError(geom, intersections);
		
		ValidationResult result = new ValidationResult();
		QualityAdeErrorVisitor visitor = new QualityAdeErrorVisitor(result);
		err.accept(visitor);
		List<AbstractErrorProperty> errors = result.getErrors();
		assertEquals(1, errors.size());
		AbstractError ae = errors.get(0).getObject();
		assertTrue(ae instanceof SolidSelfIntersectionError);
		
		SolidSelfIntersectionError adeErr = (SolidSelfIntersectionError) ae;
		assertEquals(geomId.getGmlString(), adeErr.getGeometryId());
		assertEquals(p1Id.getGmlString(), adeErr.getPolygonId1());
		assertEquals(p2Id.getGmlString(), adeErr.getPolygonId2());
	}

}
