/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.datastructure;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.Set;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.datastructure.LinearRing.LinearRingType;
import de.hft.stuttgart.citydoctor2.math.Vector3d;

/**
 * 
 * @author Matthias Betz
 *
 */
public class VertexTest {

	@Test
	public void testFromVector() {
		Vector3d vec = new Vector3d(1, 2, 3);
		Vertex v = new Vertex(vec);
		assertEquals(1, v.getX(), 0.0000001);
		assertEquals(2, v.getY(), 0.0000001);
		assertEquals(3, v.getZ(), 0.0000001);
	}
	
	@Test
	public void testGetAdjacentRings() {
		Geometry geom = new Geometry(GeometryType.SOLID, Lod.LOD1);
		
		Polygon p = new ConcretePolygon();
		geom.addPolygon(p);
		
		LinearRing lr = new LinearRing(LinearRingType.EXTERIOR);
		p.setExteriorRing(lr);
		
		Vertex v0 = new Vertex(0, 0, 0);
		lr.addVertex(v0);
		
		Set<LinearRing> adjacentRings = v0.getAdjacentRings(geom);
		assertEquals(1, adjacentRings.size());
		assertTrue(adjacentRings.contains(lr));		
	}
	
	@Test(expected = IllegalStateException.class)
	public void testGetAdjacentRingsGeometryNotContainingVertex() {
		Geometry geom = new Geometry(GeometryType.SOLID, Lod.LOD1);
		
		Polygon p = new ConcretePolygon();
		
		LinearRing lr = new LinearRing(LinearRingType.EXTERIOR);
		p.setExteriorRing(lr);
		
		Vertex v0 = new Vertex(0, 0, 0);
		lr.addVertex(v0);
		
		v0.getAdjacentRings(geom);
	}

}
