/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.math;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertSame;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.datastructure.LinearRing;
import de.hft.stuttgart.citydoctor2.datastructure.LinearRing.LinearRingType;
import de.hft.stuttgart.citydoctor2.datastructure.Vertex;

public class MovedRingTest {

	@Test
	public void testOfRing() {
		LinearRing lr = new LinearRing(LinearRingType.EXTERIOR);
		lr.addVertex(new Vertex(10, 10, 10));
		lr.addVertex(new Vertex(20, 20, 20));
		MovedRing mRing = MovedRing.ofRing(lr, new Vector3d(10, 10, 10));
		assertEquals(new Vector3d(0, 0, 0), mRing.getVertices().get(0));
		assertEquals(new Vector3d(10, 10, 10), mRing.getVertices().get(1));
	}
	
	@Test
	public void testGetOriginal() {
		LinearRing lr = new LinearRing(LinearRingType.EXTERIOR);
		lr.addVertex(new Vertex(10, 10, 10));
		lr.addVertex(new Vertex(20, 20, 20));
		MovedRing mRing = MovedRing.ofRing(lr, new Vector3d(10, 10, 10));
		assertSame(lr, mRing.getOriginal());
	}
	
	@Test
	public void testIsPointInside1() {
		LinearRing lr = new LinearRing(LinearRingType.EXTERIOR);
		lr.addVertex(new Vertex(10, 10, 10));
		lr.addVertex(new Vertex(20, 10, 10));
		lr.addVertex(new Vertex(20, 20, 10));
		lr.addVertex(new Vertex(10, 20, 10));
		lr.addVertex(new Vertex(10, 10, 10));
		MovedRing mRing = MovedRing.ofRing(lr, new Vector3d(10, 10, 10));
		assertTrue(mRing.isPointInside(new Vector3d(5, 5, 0)));
		assertFalse(mRing.isPointInside(new Vector3d(-0.1, 5, 0)));
		assertTrue(mRing.isPointInside(new Vector3d(5, 0, 0)));
		assertTrue(mRing.isPointInside(new Vector3d(0, 0, 0)));
	}
	
	@Test
	public void testIsPointInside2() {
		LinearRing lr = new LinearRing(LinearRingType.EXTERIOR);
		lr.addVertex(new Vertex(10, 10, 10));
		lr.addVertex(new Vertex(10, 20, 10));
		lr.addVertex(new Vertex(10, 20, 20));
		lr.addVertex(new Vertex(10, 10, 20));
		lr.addVertex(new Vertex(10, 10, 10));
		MovedRing mRing = MovedRing.ofRing(lr, new Vector3d(10, 10, 10));
		assertTrue(mRing.isPointInside(new Vector3d(0, 5, 5)));
		assertFalse(mRing.isPointInside(new Vector3d(0, -0.1, 5)));
		assertTrue(mRing.isPointInside(new Vector3d(0, 5, 0)));
		assertTrue(mRing.isPointInside(new Vector3d(0, 0, 0)));
	}

}
