/*-
 *  Copyright 2022 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.parser;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.util.List;

import org.citygml4j.core.ade.ADE;
import org.citygml4j.core.ade.ADERegistry;
import org.citygml4j.xml.CityGMLContext;
import org.junit.Test;

import de.hft.stuttgart.citydoctor2.datastructure.BoundarySurface;
import de.hft.stuttgart.citydoctor2.datastructure.Building;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.quality.QualityADEContext;

public class CityGml3ParserTest {

	@Test
	public void testGetContext() {
		CityGMLContext context = CityGmlParser.getContext();
		List<ADE> ades = ADERegistry.getInstance().getADEs();
		ADE ade = ades.get(0);
		assertEquals(QualityADEContext.class, ade.getClass());
		assertNotNull(context);
	}
	
	@Test
	public void testParseFileWithoutValidation() throws CityGmlParseException, InvalidGmlFileException {
		ParserConfiguration config = new ParserConfiguration(8, false);
		CityDoctorModel model = CityGmlParser.parseCityGmlFile("src/test/resources/SimpleSolid_SrefBS.gml", config);
		assertNotNull(model);
		List<Building> buildings = model.getBuildings();
		assertEquals(1, buildings.size());
		Building building = buildings.get(0);
		assertEquals("_Simple_BD.1", building.getGmlId().getGmlString());
		List<BoundarySurface> surfaces = building.getBoundarySurfaces();
		assertEquals(6, surfaces.size());
	}

}
