/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.utils;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.util.List;
import java.util.UUID;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.CheckId;
import de.hft.stuttgart.citydoctor2.check.CheckResult;
import de.hft.stuttgart.citydoctor2.check.ResultStatus;
import de.hft.stuttgart.citydoctor2.check.error.UnknownCheckError;
import de.hft.stuttgart.citydoctor2.datastructure.Building;
import de.hft.stuttgart.quality.model.enums.ResultType;
import de.hft.stuttgart.quality.model.types.CityObjectProperties;
import de.hft.stuttgart.quality.model.types.Validation;
import de.hft.stuttgart.quality.model.types.ValidationResult;

public class QualityADEUtilsTest {

	@Test
	public void testWriteQualityADE() {
		Building b = new Building();
		org.citygml4j.core.model.building.Building gmlB = new org.citygml4j.core.model.building.Building();
		b.setGmlObject(gmlB);
		List<CityObjectProperties> coADE = gmlB.getADEProperties(CityObjectProperties.class);
		assertTrue(coADE.isEmpty());
		Validation val = new Validation();
		val.setId(UUID.randomUUID().toString());
		b.addCheckResult(new CheckResult(CheckId.C_GE_P_HOLE_OUTSIDE, ResultStatus.ERROR, new UnknownCheckError(b, new NullPointerException(), CheckId.C_GE_P_HOLE_OUTSIDE)));
		QualityADEUtils.writeQualityAde(b, val);
		coADE = gmlB.getADEProperties(CityObjectProperties.class);
		assertFalse(coADE.isEmpty());
		assertEquals(1, coADE.size());
		CityObjectProperties adeComponent = coADE.get(0);
		ValidationResult valResult = adeComponent.getValidationResult().getObject();
		assertEquals(ResultType.NOT_CHECKED, valResult.getResultType());
	}

}
