/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check;

import org.yaml.snakeyaml.introspector.Property;
import org.yaml.snakeyaml.nodes.CollectionNode;
import org.yaml.snakeyaml.nodes.MappingNode;
import org.yaml.snakeyaml.nodes.Node;
import org.yaml.snakeyaml.nodes.NodeTuple;
import org.yaml.snakeyaml.nodes.SequenceNode;
import org.yaml.snakeyaml.nodes.Tag;
import org.yaml.snakeyaml.representer.Representer;

/**
 * Representer for configuration yaml files. Removing null and empty values as
 * well as class annotations
 * 
 * @author Matthias Betz
 *
 */
public class ValidationConfigurationRepresenter extends Representer {
	
	@Override
	protected NodeTuple representJavaBeanProperty(Object javaBean, Property property, Object propertyValue,
			Tag customTag) {
		if (propertyValue == null) {
			return null;
		} else {
			NodeTuple tuple = super.representJavaBeanProperty(javaBean, property, propertyValue, customTag);
			Node valueNode = tuple.getValueNode();
			if (Tag.NULL.equals(valueNode.getTag())) {
				// skip 'null' values
				return null;
			}
			return handleCollections(tuple, valueNode);
		}
	}

	private NodeTuple handleCollections(NodeTuple tuple, Node valueNode) {
		if (valueNode instanceof CollectionNode) {
			if (Tag.SEQ.equals(valueNode.getTag())) {
				SequenceNode seq = (SequenceNode) valueNode;
				if (seq.getValue().isEmpty()) {
					// skip empty lists
					return null;
				}
			}
			if (Tag.MAP.equals(valueNode.getTag())) {
				MappingNode seq = (MappingNode) valueNode;
				if (seq.getValue().isEmpty()) {
					// skip empty maps
					return null;
				}
			}
		}
		return tuple;
	}

}
