/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.checks;

import java.util.List;
import java.util.Set;

import de.hft.stuttgart.citydoctor2.check.Check;
import de.hft.stuttgart.citydoctor2.check.CheckId;
import de.hft.stuttgart.citydoctor2.check.Requirement;
import de.hft.stuttgart.citydoctor2.check.RequirementType;

/**
 * This class is for having a read only access to a check for accessing meta
 * information like parameters and type. It also can create a new instance of
 * the check. This was created to support parallel processing of multiple GML
 * files with different configurations. It isolates the configuration of a check
 * into the instance instead of having global check instances.
 * 
 * @author Matthias Betz
 *
 */
public class CheckPrototype {

	private Check c;

	public CheckPrototype(Check c) {
		this.c = c;
	}

	/**
	 * @return A new instance of the check.
	 */
	public Check createCheck() {
		return c.createNewInstance();
	}

	public CheckId getCheckId() {
		return c.getCheckId();
	}

	public List<CheckId> getDependencies() {
		return c.getDependencies();
	}

	public RequirementType getType() {
		return c.getType();
	}

	public Set<Requirement> checksRequirements() {
		return c.appliesToRequirements();
	}

}
