/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.check;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import java.io.FileNotFoundException;

import org.junit.Test;

import de.hft.stuttgart.citydoctor2.datastructure.FeatureType;
import de.hft.stuttgart.quality.model.enums.RequirementId;

public class ValidationConfigurationTest {

	@Test
	public void testLoadingConfig() throws FileNotFoundException {
		String file = "src/test/resources/testConfig.yml";
		ValidationConfiguration config = ValidationConfiguration.loadValidationConfig(file);
		assertEquals(8, config.getNumberOfRoundingPlaces());
		assertTrue(config.getRequirements().containsKey(RequirementId.R_GE_R_TOO_FEW_POINTS.toString()));
		assertFalse(config.getRequirements().get(RequirementId.R_GE_P_NON_PLANAR.toString()).isEnabled());
		assertNull(config.getFilter());
	}

	@Test
	public void testLoadingConfigWithFilter() throws FileNotFoundException {
		String file = "src/test/resources/testConfigWithFilter.yml";
		ValidationConfiguration config = ValidationConfiguration.loadValidationConfig(file);
		assertEquals(8, config.getNumberOfRoundingPlaces());
		assertTrue(config.getRequirements().containsKey(RequirementId.R_GE_R_TOO_FEW_POINTS.toString()));
		assertFalse(config.getRequirements().get(RequirementId.R_GE_P_NON_PLANAR.toString()).isEnabled());

		FilterConfiguration filterConfig = config.getFilter();
		assertNotNull(filterConfig);

		ExcludeFilterConfiguration excludeFilter = filterConfig.getExclude();
		assertNotNull(excludeFilter);

		assertTrue(excludeFilter.getIds().contains("UUID-8972-kghf-asgv"));
		assertTrue(excludeFilter.getIds().contains("UUID.*"));
		assertTrue(excludeFilter.getTypes().contains(FeatureType.BUILDING));
		assertTrue(excludeFilter.getTypes().contains(FeatureType.VEGETATION));

		IncludeFilterConfiguration includeFilter = filterConfig.getInclude();
		assertNotNull(includeFilter);

		assertTrue(includeFilter.getIds().contains(".*"));
		assertTrue(includeFilter.getTypes().contains(FeatureType.BUILDING));
		assertTrue(includeFilter.getTypes().contains(FeatureType.VEGETATION));
	}

}
