/*-
 *  Copyright 2020 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.checks.geometry;

import static org.junit.Assert.assertFalse;

import org.junit.Assert;
import org.junit.Test;

import de.hft.stuttgart.citydoctor2.check.CheckResult;
import de.hft.stuttgart.citydoctor2.check.Checker;
import de.hft.stuttgart.citydoctor2.check.ResultStatus;
import de.hft.stuttgart.citydoctor2.check.ValidationConfiguration;
import de.hft.stuttgart.citydoctor2.checks.util.GeometryTestUtils;
import de.hft.stuttgart.citydoctor2.datastructure.CityDoctorModel;
import de.hft.stuttgart.citydoctor2.datastructure.Geometry;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParseException;
import de.hft.stuttgart.citydoctor2.parser.CityGmlParser;
import de.hft.stuttgart.citydoctor2.parser.InvalidGmlFileException;

/**
 * 
 * @author Matthias Betz
 *
 */
public class SolidSelfIntCheckTest {

	@Test
	public void testGoodGeometry() {
		SolidSelfIntCheck check = new SolidSelfIntCheck();
		Geometry g = GeometryTestUtils.createGoodGeometry();
		
		check.check(g);
		CheckResult cr = g.getCheckResult(check);
		Assert.assertNotNull(cr);
		Assert.assertEquals(ResultStatus.OK, cr.getResultStatus());
	}
	
	@Test
	public void testBadGeometry() {
		SolidSelfIntCheck check = new SolidSelfIntCheck();
		Geometry g = GeometryTestUtils.createBadGeometry();
		
		check.check(g);
		CheckResult cr = g.getCheckResult(check);
		Assert.assertNotNull(cr);
		Assert.assertEquals(ResultStatus.ERROR, cr.getResultStatus());
	}
	
	@Test
	public void testSolidSelfIntTest1() throws CityGmlParseException, InvalidGmlFileException {
		ValidationConfiguration config = ValidationConfiguration.loadStandardValidationConfig();
		config.setSchematronFilePathInGlobalParameters(null);
		CityDoctorModel m = CityGmlParser.parseCityGmlFile("src/test/resources/SolidSelfIntTest1.gml", config.getParserConfiguration());
		Checker c = new Checker(config, m);
		c.runChecks();
		assertFalse(m.getBuildings().get(0).containsAnyError());
	}

}
